AnchoredOverlay class
Overlay widget with background
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AnchoredOverlay
Constructors
- AnchoredOverlay({Key? key, required Key parentKey, required bool showOverlay, required Widget overlayBuilder(BuildContext), required Widget child, Offset offset = Offset.zero, bool useCenter = false, Duration? delay = kOverlayDelay, VoidCallback? onOverlayTap, VoidCallback? onBackgroundTap})
-
Overlay widget with background
const
Properties
- child → Widget
-
Child upon which we overlay
final
- delay → Duration?
-
Delay before showing overlay
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- offset → Offset
-
Overlay offset FractionalTranslation
final
- onBackgroundTap → VoidCallback?
-
What happens when we tap on background
final
- onOverlayTap → VoidCallback?
-
What happens when we tap on overlay
final
- overlayBuilder → Widget Function(BuildContext)
-
Builder of an overlay widget
final
- parentKey → Key
-
Key to correctly identify overlay. Best to use ValueKey
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showOverlay → bool
-
Show overlay?
final
- useCenter → bool
-
Center based on screen size?
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited