OverlayData class

Simple overlay data class

Constructors

OverlayData({required Key key, required Widget content, required Rect cutout, required BuildContext? context, VoidCallback? onTap})
Simple overlay data class
const

Properties

content Widget
Overlay content (what will be displayed)
final
context BuildContext?
BuildContext of a widget upon which we insert overlay
final
cutout Rect
Rect of a widget upon which we insert overlay
final
hashCode int
The hash code for this object.
no setterinherited
key Key
Key to correctly identify overlay. Best to use ValueKey
final
onTap VoidCallback?
What happens we we tap on the overlay
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

invalid → const OverlayData
Invalid OverlayData object