OverlayManager class
Overlay manager
Here we insert/remove overlays
Constructors
- OverlayManager()
-
factory
Properties
- backgroundColor ↔ Color
-
Color of a background
getter/setter pair
- borderRadius ↔ double
-
Border radius of a cutout
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding ↔ EdgeInsets
-
Padding between cutout and its widget
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addOverlay(
OverlayData data) → void - Add overlay
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeOverlay(
Key key) → void - Remove overlay
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → OverlayManager
-
final